@@ -4,8 +4,7 @@
   SPDX-License-Identifier: GPL-2.0-only
 */
 
-#ifndef ITEMCONTEXTTEST_H
-#define ITEMCONTEXTTEST_H
+#pragma once
 
 #include <QObject>
 
@@ -14,7 +13,7 @@ class ItemContextTest : public QObject
     Q_OBJECT
 public:
     explicit ItemContextTest(QObject *parent = nullptr);
-    ~ItemContextTest();
+    ~ItemContextTest() override;
 private Q_SLOTS:
     void shouldHaveDefaultValue();
     void shouldAssignContext_data();
@@ -22,4 +21,3 @@ private Q_SLOTS:
     void shouldAssignCollection();
 };
 
-#endif // ITEMCONTEXTTEST_H
