@@ -50,9 +50,7 @@ QVector<MailFilter *> FilterImporterExporter::readFiltersFromConfig(const KShare
             filterNeedUpdate = true;
         }
         if (filter->isEmpty()) {
-#ifndef NDEBUG
             qCDebug(MAILCOMMON_LOG) << "Filter" << filter->asString() << "is empty!";
-#endif
             emptyFilters << filter->name();
             delete filter;
         } else {
@@ -96,19 +94,19 @@ void FilterImporterExporter::writeFiltersToConfig(const QVector<MailFilter *> &f
     config->sync();
 }
 
-class Q_DECL_HIDDEN FilterImporterExporter::Private
+class Q_DECL_HIDDEN FilterImporterExporter::FilterImporterExporterPrivate
 {
 public:
-    Private(QWidget *parent)
+    FilterImporterExporterPrivate(QWidget *parent)
         : mParent(parent)
     {
     }
 
     void warningInfoAboutInvalidFilter(const QStringList &emptyFilters) const;
-    QWidget *mParent = nullptr;
+    QWidget *const mParent;
 };
 
-void FilterImporterExporter::Private::warningInfoAboutInvalidFilter(const QStringList &emptyFilters) const
+void FilterImporterExporter::FilterImporterExporterPrivate::warningInfoAboutInvalidFilter(const QStringList &emptyFilters) const
 {
     if (!emptyFilters.isEmpty()) {
         KMessageBox::informationList(mParent,
@@ -121,14 +119,11 @@ void FilterImporterExporter::Private::warningInfoAboutInvalidFilter(const QStrin
 }
 
 FilterImporterExporter::FilterImporterExporter(QWidget *parent)
-    : d(new Private(parent))
+    : d(new FilterImporterExporterPrivate(parent))
 {
 }
 
-FilterImporterExporter::~FilterImporterExporter()
-{
-    delete d;
-}
+FilterImporterExporter::~FilterImporterExporter() = default;
 
 QVector<MailFilter *> FilterImporterExporter::importFilters(bool &canceled, FilterImporterExporter::FilterType type, const QString &filename)
 {
