@@ -9,7 +9,7 @@
 #include "folderselectiondialog.h"
 #include "kernel/mailkernel.h"
 #include "util/mailutil.h"
-#include <CollectionFetchJob>
+#include <Akonadi/CollectionFetchJob>
 #include <Libkdepim/LineEditCatchReturnKey>
 
 #include <KLocalizedString>
@@ -21,9 +21,9 @@
 #include <QKeyEvent>
 #include <QToolButton>
 
-namespace MailCommon
-{
-class FolderRequesterPrivate
+using namespace MailCommon;
+
+class MailCommon::FolderRequesterPrivate
 {
 public:
     Akonadi::Collection mCollection;
@@ -39,7 +39,7 @@ FolderRequester::FolderRequester(QWidget *parent)
     , d(new MailCommon::FolderRequesterPrivate)
 {
     auto hlay = new QHBoxLayout(this);
-    hlay->setContentsMargins(0, 0, 0, 0);
+    hlay->setContentsMargins({});
 
     d->mEdit = new QLineEdit(this);
     d->mEdit->setPlaceholderText(i18n("Select Folder"));
@@ -81,10 +81,7 @@ void FolderRequester::slotOpenDialog()
 }
 
 //-----------------------------------------------------------------------------
-FolderRequester::~FolderRequester()
-{
-    delete d;
-}
+FolderRequester::~FolderRequester() = default;
 
 Akonadi::Collection FolderRequester::collection() const
 {
@@ -180,4 +177,3 @@ void FolderRequester::setSelectFolderTitleDialog(const QString &title)
 {
     d->mSelectFolderTitleDialog = title;
 }
-} // namespace MailCommon
